@@ -39,8 +39,6 @@
 enum {
 	BOGUS,
 	APPLY,
-	RESTORE,
-	COMPLEXITY_CHANGE,
 	LAST_SIGNAL
 };
 
@@ -69,9 +67,7 @@ gst_dialog_apply_widget_policies (GstDialog *xd)
 {
 	GSList *list;
 
-	/* Hide, show + desensitize or show + sensitize widgets based on access level
-	 * and complexity */
-
+	/* Hide, show + desensitize or show + sensitize widgets based on access level */
 	for (list = xd->gst_widget_list; list; list = g_slist_next (list))
 	{
 		gst_widget_apply_policy (list->data);
@@ -84,47 +80,7 @@ gst_dialog_get_complexity (GstDialog *xd)
 	g_return_val_if_fail (xd != NULL, 0);
 	g_return_val_if_fail (GST_IS_DIALOG (xd), 0);
 
-	return xd->complexity;
-}
-
-void
-gst_dialog_set_complexity (GstDialog *xd, GstDialogComplexity c)
-{
-	gchar *label[] = {
-		N_(" More _Options"),
-		N_(" Fewer _Options"),
-		NULL
-	};
-
-	gchar *image[] = {
-		GTK_STOCK_ADD,
-		GTK_STOCK_REMOVE,
-		NULL
-	};
-
-	g_return_if_fail (xd != NULL);
-	g_return_if_fail (GST_IS_DIALOG (xd));
-	g_return_if_fail (c >= GST_DIALOG_BASIC);
-	g_return_if_fail (c <= GST_DIALOG_ADVANCED);
-
-	if (xd->complexity == c)
-		return;
-
-	xd->complexity = c;
-
-	if (xd->complexity == GST_DIALOG_ADVANCED)
-		gst_conf_set_boolean (xd->tool, "advanced_mode", TRUE);
-	else
-		gst_conf_set_boolean (xd->tool, "advanced_mode", FALSE);
-
-	gst_dialog_apply_widget_policies (xd);
-
-	/* set the complexity button appearance */
-	gtk_label_set_text (GTK_LABEL (xd->complexity_button_label), _(label[c]));
-	gtk_label_set_use_underline (GTK_LABEL (xd->complexity_button_label), TRUE);
-	gtk_image_set_from_stock (GTK_IMAGE (xd->complexity_button_image), image[c], GTK_ICON_SIZE_MENU);
-
-	g_signal_emit (G_OBJECT (xd), gstdialog_signals[COMPLEXITY_CHANGE], 0);
+	return GST_DIALOG_ADVANCED;
 }
 
 void
@@ -186,24 +142,6 @@ gst_dialog_thaw_visible (GstDialog *xd)
 		gtk_widget_set_sensitive (GTK_WIDGET (xd), TRUE);
 }
 
-void
-gst_dialog_set_changed_config (GstDialog *xd, gboolean value)
-{
-	g_return_if_fail (xd != NULL);
-	g_return_if_fail (GST_IS_DIALOG (xd));
-
-	xd->config_has_changed = value;
-}
-
-gboolean
-gst_dialog_get_changed_config (GstDialog *xd)
-{
-	g_return_if_fail (xd != NULL);
-	g_return_if_fail (GST_IS_DIALOG (xd));
-
-	return xd->config_has_changed;
-}
-
 gboolean
 gst_dialog_get_modified (GstDialog *xd)
 {
@@ -220,7 +158,6 @@ gst_dialog_set_modified (GstDialog *xd, gboolean state)
 	g_return_if_fail (GST_IS_DIALOG (xd));
 
 	xd->is_modified = state;
-	gtk_widget_set_sensitive (xd->apply_button, state);
 }
 
 void
@@ -244,49 +181,22 @@ gst_dialog_modify_cb (GtkWidget *w, gpointer data)
 }
 
 static void
-gst_dialog_destroy (GtkObject *tool)
+gst_dialog_class_init (GstDialogClass *class)
 {
-	GTK_OBJECT_CLASS (parent_class)->destroy (GTK_OBJECT (tool));
-}
+	GObjectClass *gobject_class;
 
-static void
-gst_dialog_class_init (GstDialogClass *klass)
-{
-	GtkObjectClass *object_class;
-
-	object_class = (GtkObjectClass *)klass;
-	parent_class = gtk_type_class (GNOME_TYPE_APP);
+	gobject_class = G_OBJECT_CLASS (class);
+	parent_class = g_type_class_peek_parent (class);
 
 	gstdialog_signals[APPLY] = 
 		g_signal_new ("apply",
-			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_OBJECT_CLASS_TYPE (gobject_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GstDialogClass, apply),
 			      NULL, NULL,
 			      gst_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
-	gstdialog_signals[RESTORE] =
-		g_signal_new ("restore",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GstDialogClass, restore),
-			      NULL, NULL,
-			      gst_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
-	
-	gstdialog_signals[COMPLEXITY_CHANGE] =
-		g_signal_new ("complexity_change",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GstDialogClass, complexity_change),
-			      NULL, NULL,
-			      gst_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
-
-	object_class->destroy = gst_dialog_destroy;
 }
 
 static void
@@ -302,8 +212,8 @@ gst_dialog_get_type (void)
 {
 	static GType gstdialog_type = 0;
 
-	if (gstdialog_type == 0) {
-		GTypeInfo gstdialog_info = {
+	if (!gstdialog_type) {
+		static const GTypeInfo gstdialog_info = {
 			sizeof (GstDialogClass),
 			NULL, /* base_init */
 			NULL, /* base finalize */
@@ -437,41 +347,6 @@ gst_dialog_widget_set_user_sensitive (GstDialog *xd, const gchar *name, gboolean
 	gst_widget_set_user_sensitive (xw, state);
 }
 
-static void
-complexity_cb (GtkWidget *w, gpointer data)
-{
-	GstDialog *dialog;
-
-	g_return_if_fail (data != NULL);
-	g_return_if_fail (GST_IS_DIALOG (data));
-
-	dialog = GST_DIALOG (data);
-
-	switch (dialog->complexity) {
-	case GST_DIALOG_BASIC:
-		gst_dialog_set_complexity (dialog, GST_DIALOG_ADVANCED);
-		break;
-	case GST_DIALOG_ADVANCED:
-		gst_dialog_set_complexity (dialog, GST_DIALOG_BASIC);
-		break;
-	default:
-		break;
-	}
-}
-
-static void
-restore_config (gpointer data)
-{
-	GstDialog *dialog;
-
-	g_return_if_fail (data != NULL);
-	g_return_if_fail (GST_IS_DIALOG (data));
-
-	dialog = GST_DIALOG (data);
-
-	g_signal_emit (G_OBJECT (dialog), gstdialog_signals[RESTORE], 0);
-}
-
 static void
 apply_config (gpointer data)
 {
@@ -526,29 +401,7 @@ dialog_close (GstDialog *dialog)
 	gtk_widget_hide (GTK_WIDGET (dialog));
 
 	if (dialog == dialog->tool->main_dialog)
-		g_signal_emit_by_name (GTK_OBJECT (dialog->tool), "close");
-}
-
-static void
-dialog_delete_event_cb (GtkWidget *w, GdkEvent *event, gpointer data)
-{
-	dialog_close (data);
-}
-
-static void
-apply_cb (GtkWidget *w, gpointer data)
-{
-	GstDialog *dialog;
-
-	g_return_if_fail (data != NULL);
-	g_return_if_fail (GST_IS_DIALOG (data));
-
-	dialog = GST_DIALOG (data);
-
-	gst_dialog_set_changed_config (dialog, TRUE);
-
-	if (gst_dialog_get_modified (dialog))
-		apply_config (dialog);
+		g_signal_emit_by_name (G_OBJECT (dialog->tool), "close");
 }
 
 static void
@@ -556,14 +409,11 @@ cancel_cb (GtkWidget *w, gpointer data)
 {
 	GstDialog *dialog;
 
-	g_return_if_fail (data!= NULL);
+	g_return_if_fail (data != NULL);
 	g_return_if_fail (GST_IS_DIALOG (data));
 
 	dialog = GST_DIALOG (data);
 
-	if (gst_dialog_get_changed_config (dialog))
-		restore_config (dialog);
-
 	dialog_close (dialog);
 }
 
@@ -586,15 +436,16 @@ accept_cb (GtkWidget *w, gpointer data)
 static void
 help_cb (GtkWidget *w, gpointer data)
 {
+	GstDialog *gst_dialog;
+
+	gst_dialog = GST_DIALOG (data);
+	gst_tool_show_help (gst_dialog->tool, NULL);
 }
 
-void
-gst_dialog_enable_complexity (GstDialog *dialog)
+static void
+dialog_delete_event_cb (GtkWidget *w, GdkEvent *event, gpointer data)
 {
-	g_return_if_fail (dialog != NULL);
-	g_return_if_fail (GST_IS_DIALOG (dialog));
-
-	gtk_widget_show (dialog->complexity_button);
+	cancel_cb (w, data);
 }
 
 static void
@@ -644,11 +495,10 @@ void
 gst_dialog_construct (GstDialog *dialog, GstTool *tool,
 		      const char *widget, const char *title)
 {
-	GladeXML *xml;
-	GtkWidget *w;
-	GtkStockItem item;
-	gboolean val;
-	char *s;
+	GladeXML     *xml;
+	GtkWidget    *w;
+	char         *s;
+	GtkSizeGroup *size_group;
 
 	g_return_if_fail (dialog != NULL);
 	g_return_if_fail (GST_IS_DIALOG (dialog));
@@ -680,45 +530,23 @@ gst_dialog_construct (GstDialog *dialog, GstTool *tool,
 	gtk_widget_unparent (dialog->child);
 	gtk_box_pack_start (GTK_BOX (w), dialog->child, TRUE, TRUE, 0);
 
+	size_group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
+
 	w = glade_xml_get_widget (xml, "help");
 	g_signal_connect (G_OBJECT (w), "clicked", G_CALLBACK (help_cb), dialog);
-	/* FIXME: help button hidden until the help files are ready. */
-	gtk_widget_hide (w);
+	gtk_size_group_add_widget (size_group, w);
 
-	w = glade_xml_get_widget (xml, "complexity");
-	g_signal_connect (GTK_OBJECT (w), "clicked", G_CALLBACK (complexity_cb), dialog);
-
-	dialog->complexity_button = w;
-
-	w = glade_xml_get_widget (xml, "complexity_button_label");
-	dialog->complexity_button_label = w;
-
-	w = glade_xml_get_widget (xml, "complexity_button_image");
-	dialog->complexity_button_image = w;
-
-	w = glade_xml_get_widget (xml, "apply");
-	g_signal_connect (G_OBJECT (w), "clicked", G_CALLBACK (apply_cb), dialog);
-	dialog->apply_button = w;
-	
 	w = glade_xml_get_widget (xml, "cancel");
 	g_signal_connect (G_OBJECT (w), "clicked", G_CALLBACK (cancel_cb), dialog);
+	gtk_size_group_add_widget (size_group, w);
 
 	w = glade_xml_get_widget (xml, "accept");
-	g_signal_connect (GTK_OBJECT (w), "clicked", G_CALLBACK (accept_cb), dialog);
+	g_signal_connect (G_OBJECT (w), "clicked", G_CALLBACK (accept_cb), dialog);
+	gtk_size_group_add_widget (size_group, w);
 	
 	gst_dialog_set_modified (dialog, FALSE);
-	gst_dialog_set_changed_config (dialog, FALSE);
-	gtk_widget_hide (dialog->complexity_button);
-
-	dialog->complexity = GST_DIALOG_NONE;
-	val = gst_conf_get_boolean (dialog->tool, "advanced_mode");
-	if (val == FALSE)
-		val = GST_DIALOG_BASIC;
-
-	gst_dialog_set_complexity (dialog, val);
 
 	g_signal_connect (G_OBJECT (dialog), "delete_event", G_CALLBACK (dialog_delete_event_cb), dialog);
-
 	g_signal_connect (G_OBJECT (tool->remote_dialog), "delete_event", G_CALLBACK (dialog_delete_event_cb), dialog);
 
 }
