@@ -58,35 +58,47 @@ static GstNetworkInterfaceDescription gst_iface_desc [] = {
 	{ NULL,                          GST_CONNECTION_UNKNOWN,  NULL,             NULL,         NULL }
 };
 
-GtkItemFactoryEntry connection_popup_menu_items[] = {
-	{ N_("/_Add ..."), NULL, G_CALLBACK (on_connection_popup_add_activate), CONNECTION_POPUP_ADD, "<StockItem>", GTK_STOCK_ADD},
-	{ "/" , NULL, NULL, CONNECTION_POPUP_SEPARATOR, "<Separator>", NULL},
-	{ N_("/_Configure"), NULL, G_CALLBACK (on_connection_popup_configure_activate), CONNECTION_POPUP_CONFIGURE, "<StockItem>", GTK_STOCK_PREFERENCES },
-	{ N_("/_Delete"), NULL, G_CALLBACK (on_connection_popup_delete_activate), CONNECTION_POPUP_DELETE, "<StockItem>", GTK_STOCK_DELETE },
+static GtkActionEntry connection_popup_menu_items [] = {
+	{ "Add",        GTK_STOCK_ADD,        N_("_Add"),        NULL, NULL, G_CALLBACK (on_connection_popup_add_activate)       },
+	{ "Properties", GTK_STOCK_PROPERTIES, N_("_Properties"), NULL, NULL, G_CALLBACK (on_connection_popup_configure_activate) },
+	{ "Delete",     GTK_STOCK_DELETE,     N_("_Delete"),     NULL, NULL, G_CALLBACK (on_connection_popup_delete_activate)    },
 };
 
+const gchar *connection_ui_description =
+	"<ui>"
+	"  <popup name='MainMenu'>"
+	"    <menuitem action='Add'/>"
+	"    <separator/>"
+	"    <menuitem action='Properties'/>"
+	"    <menuitem action='Delete'/>"
+	"  </popup>"
+	"</ui>";
+
 #define GET_STR(yy_prefix,xx) g_free (cxn->xx); \
 	cxn->xx = gtk_editable_get_chars (GTK_EDITABLE (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx)), 0, -1)
+#define GET_COMBO_STR(yy_prefix,xx) g_free (cxn->xx); \
+	cxn->xx = gtk_editable_get_chars (GTK_EDITABLE (GTK_BIN (GTK_COMBO_BOX (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx)))->child), 0, -1)
 #define GET_BOOL(yy_prefix,xx) cxn->xx = GTK_TOGGLE_BUTTON (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx))->active
 #define GET_BOOL_NOT(yy_prefix,xx) GET_BOOL(yy_prefix,xx); cxn->xx = !cxn->xx;
 #define GET_INT(yy_prefix,xx) cxn->xx = gtk_range_get_value (GTK_RANGE (GTK_SCALE (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx))))
-#define GET_DIAL_OPTION_MENU(yy_prefix, xx) cxn->xx = (gtk_option_menu_get_history (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx))) == 0)? g_strdup ("ATDT"): g_strdup ("ATDP")
+#define GET_DIAL_COMMAND(yy_prefix, xx) cxn->xx = (gtk_combo_box_get_active (GTK_COMBO_BOX (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx))) == 0)? g_strdup ("ATDT"): g_strdup ("ATDP")
 #define SET_STR(yy_prefix,xx) gst_ui_entry_set_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx)), cxn->xx)
+#define SET_COMBO_STR(yy_prefix,xx) gst_ui_entry_set_text (GTK_ENTRY (GTK_BIN (GTK_COMBO_BOX (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx)))->child), cxn->xx)
 #define SET_BOOL(yy_prefix,xx) gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx)), cxn->xx)
 #define SET_BOOL_NOT(yy_prefix,xx) gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx)), !cxn->xx)
 #define SET_INT(yy_prefix,xx) gtk_range_set_value (GTK_RANGE (GTK_SCALE (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx))), cxn->xx)
-#define SET_DIAL_OPTION_MENU(yy_prefix, xx) gtk_option_menu_set_history (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx)), ((cxn->xx != NULL) && (g_ascii_strcasecmp (cxn->xx, "ATDP") == 0))?1:0)
+#define SET_DIAL_COMMAND(yy_prefix, xx) gtk_combo_box_set_active (GTK_COMBO_BOX (gst_dialog_get_widget (tool->main_dialog, yy_prefix#xx)), ((cxn->xx != NULL) && (g_ascii_strcasecmp (cxn->xx, "ATDP") == 0))?1:0)
 
 typedef struct {
 	GtkWidget *list;
-	GtkWidget *def_gw_omenu;
+	GtkWidget *def_gw_menu;
 } GstConnectionUI;
 
 #define CONNECTION_UI_STRING "connection_ui"
 
 /*static GSList *connections;*/
 
-GstTool *tool;
+extern GstTool *tool;
 
 static gboolean
 connection_xml_get_boolean (xmlNode *node, gchar *elem)
@@ -437,28 +449,6 @@ connection_get_dev_type (GstConnection *cxn)
 	return NULL;
 }
 
-static char *
-connection_item_factory_trans (const char *path, gpointer data)
-{
-	return _((gchar*)path);
-}
-
-static GtkItemFactory *
-connection_popup_item_factory_create (GtkWidget *treeview)
-{
-	GtkItemFactory *item_factory;
-
-	g_return_val_if_fail (treeview != NULL, NULL);
-
-	item_factory = gtk_item_factory_new (GTK_TYPE_MENU, "<main>", NULL);
-	gtk_item_factory_set_translate_func (item_factory, connection_item_factory_trans,
-					     NULL, NULL);
-	gtk_item_factory_create_items (item_factory, G_N_ELEMENTS (connection_popup_menu_items),
-				       connection_popup_menu_items, (gpointer) treeview);
-
-	return item_factory;
-}
-
 static GtkTreeModel *
 connection_list_model_new (void)
 {
@@ -528,26 +518,10 @@ connection_list_select_row (GtkTreeSelection *selection, gpointer data)
 	GtkTreeIter     iter;
 	GtkTreeModel   *model;
 	GstConnection  *cxn;
-	GtkItemFactory *factory;
 
-	factory = (GtkItemFactory *) data;
-
-	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-		gtk_tree_model_get (model, &iter, CONNECTION_LIST_COL_DATA, &cxn, -1);
-
-		if (cxn->type == GST_CONNECTION_LO) {
-			connection_actions_set_sensitive (FALSE);
-			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, CONNECTION_POPUP_DELETE),
-				FALSE);
-		}
-		else {
-			connection_actions_set_sensitive (TRUE);
-			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, CONNECTION_POPUP_DELETE),
-				TRUE);
-		}
-	} else
+	if (gtk_tree_selection_get_selected (selection, &model, &iter))
+		connection_actions_set_sensitive (TRUE);
+	else
 		connection_actions_set_sensitive (FALSE);
 }
 
@@ -602,7 +576,7 @@ connection_iter (GstConnection *cxn, GtkTreeIter *iter)
 	while (valid) {
 		gtk_tree_model_get (model, iter, CONNECTION_LIST_COL_DATA, &c, -1);
 
-		/* we've got two possibilities here, cxn->may be NULL, in such case
+		/* we've got two possibilities here, cxn->file may be NULL, in such case
 		 * we need to compare with the interface */
 		if (((cxn->file != NULL) && (strcmp (cxn->file, c->file) == 0)) ||
 		    ((cxn->file == NULL) && (strcmp (cxn->dev, c->dev) == 0)))
@@ -634,7 +608,7 @@ connection_list_new (GstTool *tool)
 	GtkWidget        *treeview;
 	GtkTreeSelection *select;
 	GtkTreeModel     *model;
-	GtkItemFactory   *item_factory;
+	GtkWidget        *popup;
 
 	model = connection_list_model_new ();
 
@@ -644,17 +618,22 @@ connection_list_new (GstTool *tool)
 
 	connection_list_add_columns (GTK_TREE_VIEW (treeview));
 
-	item_factory = connection_popup_item_factory_create (treeview);
+	popup = create_popup_menu (treeview,
+				   connection_popup_menu_items,
+				   G_N_ELEMENTS (connection_popup_menu_items),
+				   connection_ui_description);
 
 	g_signal_connect (G_OBJECT (treeview), "button_press_event",
 			  G_CALLBACK (callbacks_button_press),
-			  (gpointer) item_factory);
+			  (gpointer) popup);
+	g_signal_connect (G_OBJECT (treeview), "popup-menu",
+			  G_CALLBACK (on_table_popup_menu), popup);
 	
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
 	g_signal_connect (G_OBJECT (select), "changed",
 			  G_CALLBACK (connection_list_select_row),
-			  (gpointer) item_factory); 
+			  (gpointer) popup); 
 
 	gtk_widget_show_all (treeview);
 
@@ -1019,45 +998,51 @@ connection_init_gui (GstTool *tool)
 
 	ui->list = connection_list_new (tool);
 
-	ui->def_gw_omenu = gst_dialog_get_widget (tool->main_dialog, "connection_def_gw_omenu");
+	ui->def_gw_menu = gst_dialog_get_widget (tool->main_dialog, "connection_def_gw_menu");
 
 	g_object_set_data (G_OBJECT (tool), CONNECTION_UI_STRING, (gpointer) ui);
 
-	for (i = GST_CONNECTION_OTHER; i < GST_CONNECTION_LAST; i++)
-		gst_iface_desc[i].pixbuf = load_pixbuf (gst_iface_desc[i].icon);
+	for (i = 0; i < G_N_ELEMENTS (gst_iface_desc); i++)
+		if (gst_iface_desc[i].icon)
+			gst_iface_desc[i].pixbuf = load_pixbuf (gst_iface_desc[i].icon);
 }
 
-/* NULL if false, else GtkWidget in data in found node */
-static GtkWidget *
-connection_default_gw_find_item (GtkWidget *omenu, gchar *dev)
+/* returns -1 if the device is not found */
+static gint
+connection_default_gw_find_item (GtkWidget *menu, gchar *dev)
 {
-	GList *l;
-	gchar *value;
+	GtkTreeModel *model;
+	GtkTreeIter   iter;
+	gboolean      valid;
+	gint          nitem;
+	gchar        *value;
 
-	for (l = g_object_get_data (G_OBJECT (omenu), "list");
-	     l; l = l->next) {
-		value = g_object_get_data (G_OBJECT (l->data), "value");
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (menu));
+	valid = gtk_tree_model_get_iter_first (model, &iter);
+	nitem = 0;
 
-		if (!strcmp (dev, value))
-			return l->data;
+	while (valid) {
+		gtk_tree_model_get (model, &iter, 0, &value, -1);
+
+		if (strcmp (dev, value) == 0) {
+			g_free (value);
+			return nitem;
+		}
+
+		nitem++;
+		g_free (value);
+		valid = gtk_tree_model_iter_next (model, &iter);
 	}
 
-	return NULL;
-}
-
-static void
-connection_default_gw_activate (GtkMenuItem *item, gpointer data)
-{
-	g_object_set_data (G_OBJECT (tool), "gatewaydev", data);
+	return -1;
 }
 
 void
 connection_default_gw_add (GstConnection *cxn)
 {
-	GtkWidget *omenu, *menu, *item;
-	GList *l;
-	gchar *cpy, *dev;
 	GstConnectionUI *ui;
+	GtkWidget       *menu;
+	gchar           *dev;
 
 	dev = cxn->dev;
 	
@@ -1067,87 +1052,54 @@ connection_default_gw_add (GstConnection *cxn)
 	ui = (GstConnectionUI *)g_object_get_data (G_OBJECT (tool), CONNECTION_UI_STRING);
 
 	g_return_if_fail (ui != NULL);
-	
-	omenu = ui->def_gw_omenu;
-	menu  = gtk_option_menu_get_menu (GTK_OPTION_MENU (omenu));
+
+	menu = ui->def_gw_menu;
 
 	if (!cxn->gateway || !*cxn->gateway)
 		return;
 
-	if (connection_default_gw_find_item (omenu, dev))
+	if (connection_default_gw_find_item (menu, dev) != -1)
 		return;
-	
-	cpy = g_strdup (dev);
-	item = gtk_menu_item_new_with_label (dev);
-	g_signal_connect (G_OBJECT (item), "activate",
-			    G_CALLBACK (connection_default_gw_activate),
-			    (gpointer) cpy);
-	g_object_set_data (G_OBJECT (item), "value", cpy);
-	gtk_widget_show (item);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-	
-	l = g_object_get_data (G_OBJECT (omenu), "list");
-	l = g_list_append (l, item);
-	g_object_set_data (G_OBJECT (omenu), "list", l);
+
+	gtk_combo_box_append_text (GTK_COMBO_BOX (menu), dev);
 }
 
 void
 connection_default_gw_remove (gchar *dev)
 {
-	GtkWidget *omenu, *menu, *item;
-	GList *l;
-	gchar *cpy;
 	GstConnectionUI *ui;
+	GtkWidget       *menu;
+	gint             nitem;
 
 	ui = (GstConnectionUI *)g_object_get_data (G_OBJECT (tool), CONNECTION_UI_STRING);
 
-	omenu = ui->def_gw_omenu;
-	menu  = gtk_option_menu_get_menu (GTK_OPTION_MENU (omenu));
+	menu = ui->def_gw_menu;
 
-	item = connection_default_gw_find_item (omenu, dev);
+	nitem = connection_default_gw_find_item (menu, dev);
 
-	if (!item)
+	if (nitem == -1)
 		return;
-	
-	l = g_object_get_data (G_OBJECT (omenu), "list");
-	l = g_list_remove (l, item);
-	g_object_set_data (G_OBJECT (omenu), "list", l);
 
-	cpy = g_object_get_data (G_OBJECT (item), "value");
-	g_free (cpy);
-	
-	gtk_widget_destroy (item);
+	gtk_combo_box_remove_text (GTK_COMBO_BOX (menu), nitem);
 }
 
 void
 connection_default_gw_init (GstTool *tool, gchar *dev)
 {
-	GtkWidget *omenu, *menu, *item;
 	GstConnectionUI *ui;
+	GtkWidget       *menu;
+	gint             nitem;
 
 	ui = (GstConnectionUI *)g_object_get_data (G_OBJECT (tool), CONNECTION_UI_STRING);
 
 	g_return_if_fail (ui != NULL);
 
-	omenu = ui->def_gw_omenu;
-	menu  = gtk_option_menu_get_menu (GTK_OPTION_MENU (omenu));
+	menu = ui->def_gw_menu;
 
-	item = gtk_menu_get_active (GTK_MENU (menu));
-	g_signal_connect (G_OBJECT (item), "activate",
-			    G_CALLBACK (connection_default_gw_activate),
-			    (gpointer) NULL);
-	/* Strange bug caused the "Auto" item to be unsensitive the first time. */
-	gtk_menu_shell_select_item (GTK_MENU_SHELL (menu), item);
-	
-	item = connection_default_gw_find_item (omenu, dev);
-	if (item) {
-		GList *l;
+	nitem = connection_default_gw_find_item (menu, dev);
 
-		l = g_object_get_data (G_OBJECT (omenu), "list");
-		
-		gtk_option_menu_set_history (GTK_OPTION_MENU (omenu), g_list_index (l, item) + 1);
-		gtk_menu_shell_select_item (GTK_MENU_SHELL (menu), item);
-	}
+	if (nitem != -1)
+		gtk_combo_box_set_active (GTK_COMBO_BOX (menu), nitem);
 }
 
 GstConnection *
@@ -1651,6 +1603,46 @@ connection_set_bcast_and_network (GstConnection *cxn)
 	g_free (network);
 }
 
+void
+connection_fill_ip_menu (GtkWidget *menu)
+{
+       GtkTreeModel *model;
+       IPConfigType  i;
+       char *bootproto_labels[] = {
+               N_("Manual"),
+               N_("Automatic (DHCP)"),
+               N_("Automatic (BOOTP)")
+       };
+
+       g_return_if_fail (menu != NULL);
+
+       model = gtk_combo_box_get_model (GTK_COMBO_BOX (menu));
+       gtk_list_store_clear (GTK_LIST_STORE (model));
+
+       for (i = 0; i < 3; i++)
+               gtk_combo_box_append_text (GTK_COMBO_BOX (menu), _(bootproto_labels[i]));
+}
+
+void
+connection_fill_dial_menu (GtkWidget *menu)
+{
+	GtkTreeModel *model;
+	gint i;
+	char *dial_types[] = {
+		N_("Tones"),
+		N_("Pulses"),
+		NULL
+	};
+
+	g_return_if_fail (menu != NULL);
+
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (menu));
+	gtk_list_store_clear (GTK_LIST_STORE (model));
+
+	for (i = 0; dial_types[i]; i++)
+		gtk_combo_box_append_text (GTK_COMBO_BOX (menu), _(dial_types[i]));
+}
+
 static void
 empty_general (GstConnection *cxn)
 {
@@ -1690,13 +1682,13 @@ empty_ppp (GstConnection *cxn)
 	GET_STR ("ppp_", password);
 	GET_BOOL ("ppp_", persist);
 	GET_INT ("ppp_", volume);
-	GET_DIAL_OPTION_MENU ("ppp_", dial_command);
+	GET_DIAL_COMMAND ("ppp_", dial_command);
 }
 
 static void
 empty_ppp_adv (GstConnection *cxn)
 {
-	GET_STR ("ppp_", serial_port);
+	GET_COMBO_STR ("ppp_", serial_port);
 	GET_BOOL ("ppp_", stupid);
 	GET_BOOL ("ppp_", set_default_gw);
 	GET_BOOL_NOT ("ppp_", update_dns);
@@ -1742,7 +1734,7 @@ connection_validate (GstConnection *cxn, GtkWidget *parent)
 			primary_text   = _("Error in IP address");
 			secondary_text = _("The IP address or netmask for the interface "
 					   "was left empty. Please enter valid IP "
-					   "addresses in those fields to continue.");
+					   "addresses in those fields to continue");
 		}
 		
 		break;
@@ -1752,30 +1744,30 @@ connection_validate (GstConnection *cxn, GtkWidget *parent)
 			primary_text   = _("Error in IP address");
 			secondary_text = _("The IP address or remote address for the "
 					   "interface was left empty. Please enter valid "
-					   "IP addresses in those fields to continue.");
+					   "IP addresses in those fields to continue");
 		}
 		
 		break;
 	case GST_CONNECTION_PPP:
 		if (!cxn->update_dns && strempty (cxn->dns1)) {
-			primary_text   = _("Error in DNS servers");
-			secondary_text = _("You chose to set the DNS servers for this "
+			primary_text   = _("Error in domain name servers");
+			secondary_text = _("You chose to set the domain name servers for this "
 					   "connection manually, but left the IP "
-					   "address for the primary DNS empty. Please "
-					   "enter the IP for the primary DNS or uncheck "
-					   "the manual DNS option.");
+					   "address for the primary name server empty. Please "
+					   "enter the IP for the primary domain name server or uncheck "
+					   "the manual DNS option");
 			
 		} else if (strempty (cxn->serial_port)) {
 			primary_text   = _("Invalid modem device");
 			secondary_text = _("The modem device that the connection "
 					   "will use was left empty. Please enter "
 					   "a device or press \"autodetect\" to "
-					   "continue.");
+					   "continue");
 		} else if (strempty (cxn->phone_number)) {
 			primary_text   = _("Invalid phone number");
 			secondary_text = _("The phone number that the connection "
 					   "will use was left empty. Please enter "
-					   "a valid phone number to continue.");
+					   "a valid phone number to continue");
 		}
 		
 		break;
@@ -1835,13 +1827,15 @@ fill_general (GstConnection *cxn)
 	SET_BOOL ("status_", user);
 }
 
-static void
-update_ip_config (GstConnection *cxn)
+void
+connection_update_ip_config (GstConnection *cxn)
 {
 	IPConfigType ip;
 	gboolean sensitive;
-	
-	ip = cxn->tmp_ip_config;
+	GtkWidget *menu;
+
+	menu = gst_dialog_get_widget (tool->main_dialog, "connection_config");
+	ip   = gtk_combo_box_get_active (GTK_COMBO_BOX (menu));
 	sensitive = (ip == IP_MANUAL);
 
 	SET_BOOL ("ip_", update_dns);
@@ -1855,66 +1849,30 @@ update_ip_config (GstConnection *cxn)
 	gtk_widget_set_sensitive (gst_dialog_get_widget (tool->main_dialog, "ip_gateway_label"), sensitive);
 }
 
-static void
-ip_config_menu_cb (GtkWidget *w, gpointer data)
-{
-	GstConnection *cxn;
-	IPConfigType ip;
-
-	cxn = g_object_get_data (G_OBJECT (w), "user_data");
-
-	if (cxn->frozen)
-		return;
-
-	ip = GPOINTER_TO_INT (data);
-
-	if (cxn->tmp_ip_config == ip)
-		return;
-
-	cxn->tmp_ip_config = ip;
-
-	connection_set_modified (cxn, TRUE);
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gst_dialog_get_widget (tool->main_dialog, "ip_update_dns")),
-				      ip != IP_MANUAL);
-
-	update_ip_config (cxn);
-}
-
 static void
 fill_ip (GstConnection *cxn)
 {
-	GtkWidget *menu, *menuitem, *omenu;
-	IPConfigType i;
+	GtkWidget    *menu;
+	IPConfigType  i;
 
-	char *bootproto_labels[] = {
-		N_("Manual"),
-		N_("Automatic (DHCP)"),
-		N_("Automatic (BOOTP)")
-	};
+	menu = gst_dialog_get_widget (tool->main_dialog, "connection_config");
 
-	omenu = gst_dialog_get_widget (tool->main_dialog, "connection_config");
+	g_signal_handlers_block_matched (G_OBJECT (menu), G_SIGNAL_MATCH_FUNC,
+					 0, 0, NULL, G_CALLBACK (on_connection_ip_config_changed), NULL);
 
-	menu = gtk_menu_new ();
-	for (i = 0; i < 3; i++) {
-		menuitem = gtk_menu_item_new_with_label (_(bootproto_labels[i]));
-		g_object_set_data (G_OBJECT (menuitem), "user_data", cxn);
-		g_signal_connect (G_OBJECT (menuitem), "activate",
-				  G_CALLBACK (ip_config_menu_cb),
-				  GINT_TO_POINTER (i));
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	}
-	gtk_widget_show_all (menu);
+	connection_fill_ip_menu (menu);
+	g_object_set_data (G_OBJECT (menu), "cxn", cxn);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (menu), cxn->ip_config);
 
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (omenu), menu);
-	gtk_option_menu_set_history (GTK_OPTION_MENU (omenu), cxn->ip_config);	
+	g_signal_handlers_unblock_matched (G_OBJECT (menu), G_SIGNAL_MATCH_FUNC,
+					   0, 0, NULL, G_CALLBACK (on_connection_ip_config_changed), NULL);
 
-	update_ip_config (cxn);
+	connection_update_ip_config (cxn);
 
 	SET_BOOL ("ip_", update_dns);
-	SET_STR ("ip_", address);
-	SET_STR ("ip_", netmask);
-	SET_STR ("ip_", gateway);
+	SET_STR  ("ip_", address);
+	SET_STR  ("ip_", netmask);
+	SET_STR  ("ip_", gateway);
 }
 
 static void
@@ -1926,19 +1884,24 @@ fill_wlan (GstConnection *cxn)
 static void
 fill_ppp (GstConnection *cxn)
 {
+	GtkWidget *menu;
+
+	menu = gst_dialog_get_widget (tool->main_dialog, "ppp_dial_command");
+	connection_fill_dial_menu (menu);
+	
 	SET_STR ("ppp_", phone_number);
 	SET_STR ("ppp_", external_line);
 	SET_STR ("ppp_", login);
 	SET_STR ("ppp_", password);
 	SET_BOOL ("ppp_", persist);
 	SET_INT ("ppp_", volume);
-	SET_DIAL_OPTION_MENU ("ppp_", dial_command);
+	SET_DIAL_COMMAND ("ppp_", dial_command);
 }
 
 static void
 fill_ppp_adv (GstConnection *cxn)
 {
-	SET_STR ("ppp_", serial_port);
+	SET_COMBO_STR ("ppp_", serial_port);
 	SET_BOOL ("ppp_", stupid);
 	SET_BOOL ("ppp_", set_default_gw);
 	SET_BOOL_NOT ("ppp_", update_dns);
@@ -1975,8 +1938,6 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 	fill_general (cxn);
 
 	if (cxn->type == GST_CONNECTION_PPP) {
-		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
-					 PIXMAPS_DIR "/ppp.png");
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), TRUE);
 		gtk_container_set_border_width (GTK_CONTAINER (container), 12);
 
@@ -1994,8 +1955,6 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
 	} else if (cxn->type == GST_CONNECTION_WLAN) {
-		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
-					 PIXMAPS_DIR "/wavelan-48.png");
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_container_set_border_width (GTK_CONTAINER (container), 0);
@@ -2010,8 +1969,6 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 		fill_ip (cxn);
 		fill_wlan (cxn);
 	} else if (cxn->type == GST_CONNECTION_ETH) {
-		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
-					 PIXMAPS_DIR "/connection-ethernet.png");
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_container_set_border_width (GTK_CONTAINER (container), 0);
@@ -2025,8 +1982,6 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 
 		fill_ip (cxn);
 	} else if (cxn->type == GST_CONNECTION_PLIP) {
-		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
-					 PIXMAPS_DIR "/plip-48.png");
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_container_set_border_width (GTK_CONTAINER (container), 0);
@@ -2040,8 +1995,6 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 
 		fill_ptp (cxn);
 	} else if (cxn->type == GST_CONNECTION_IRLAN) {
-		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
-					 PIXMAPS_DIR "/irda-48.png");
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_container_set_border_width (GTK_CONTAINER (container), 0);
@@ -2055,9 +2008,6 @@ connection_dialog_setup_widgets (GstConnection *cxn)
 
 		fill_ip (cxn);
 	} else {
-		gtk_image_set_from_file (GTK_IMAGE (gst_dialog_get_widget (tool->main_dialog, "connection_pixmap")),
-					 PIXMAPS_DIR "/network.png");
-
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 		gtk_container_set_border_width (GTK_CONTAINER (container), 0);
@@ -2141,12 +2091,12 @@ connection_configure_device (xmlNodePtr root, gchar *interface)
 		}
 
 		if (!dev_node) {
-			primary_text   = g_strdup (_("Nonexisting interface"));
-			secondary_text = g_strdup_printf (_("The interface \"%s\" doesn't exist."), interface);
+			primary_text   = g_strdup_printf (_("The interface \"%s\" doesn't exist"), interface);
+			secondary_text = NULL;
 		}
 	} else {
 		primary_text   = g_strdup (_("Invalid interface"));
-		secondary_text = g_strdup (_("The loopback interface cannot be configured."));
+		secondary_text = g_strdup (_("The loopback interface cannot be configured"));
 	}
 
 	if (!primary_text) {
